.. include:: ../README.rst

.. toctree::
   :maxdepth: 2
   :caption: Project Operations

   versioning

***
API
***

.. toctree::
   :maxdepth: 2
   :caption: Informational Only

   lib/api/index

.. include:: ../CHANGELOG.rst
